#include <SDL/SDL.h>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>

/* constante pentru rezolutia grafica */
#define SCREEN_WIDTH 640
#define SCREEN_HEIGHT 480

void deseneaza_patrat(SDL_Surface * screen) {
  SDL_Rect r;
  /* dimensiunea fiecarui patrat: 32x32 pixeli */
  r.w = r.h = 32;
  /* plasam patratul curent la coordonate aleatoare */
  r.x = rand() % (SCREEN_WIDTH - r.w);
  r.y = rand() % (SCREEN_HEIGHT - r.h);
  /* alegem aleator valori pentru componentele de 
     culoare: rosu, verde si albastru */
  Uint8 rosu = rand() % 256;
  Uint8 verde = rand() % 256;
  Uint8 albastru = rand() % 256;
  /* mapam componentele rosu, verde si albastru pe 
     adancimea de culoare a ecranului */
  Uint32 culoare =
      SDL_MapRGB(screen->format, rosu, verde, albastru);
  /* desenam patratul curent */
  SDL_FillRect(screen, &r, culoare);
}

int main(int argc, char **argv) {
  /* initializare generator numere aleatoare */
  srand(time(NULL));
  /* initializare SDL */
  if (SDL_Init(SDL_INIT_VIDEO) == -1) {
    printf("Failed to initialize SDL: %s.\n", SDL_GetError());
    exit(EXIT_FAILURE);
  }
  atexit(SDL_Quit);
  /* configurare mod video */
  SDL_Surface *screen =
      SDL_SetVideoMode(SCREEN_WIDTH, SCREEN_HEIGHT, 8,
                       SDL_SWSURFACE);
  if (screen == NULL) {
    printf("Failed to set video mode: %s.\n", SDL_GetError());
    exit(EXIT_FAILURE);
  }

  /* bucla principala de program:
     - desenam patrate colorate
     - pana cand utilizatorul apasa ESC */
  SDL_Event event;
  int gata = 0;
  while (!gata) {
    /* desenam pe suprafata grafica din memorie */
    deseneaza_patrat(screen);
    /* afisam suprafata grafica pe ecran */
    SDL_Flip(screen);
    /* daca si cat timp utilizatorul apasa taste, 
       reactionam la ele */
    while (SDL_PollEvent(&event)) {
      switch (event.type) {
        /* daca e apasare de tasta */
      case SDL_KEYDOWN:
        /* daca e tasta ESCAPE vom iesi din program */
        if (event.key.keysym.sym == SDLK_ESCAPE)
          gata = 1;
        break;
        /* daca se inchide fereastra vom iesi din program */
      case SDL_QUIT:
        gata = 1;
        break;
      }
    }
  }

  /* eliberare resurse folosite */
  SDL_Quit();
  exit(EXIT_SUCCESS);
}
